# RadicalPy: a toolbox for radical pair spin dynamics

RadicalPy in an intuitive (object-oriented) open-source Python
framework specific to radical pair spin dynamics.

To get started take a look at the [quick start
guide](https://github.com/Spin-Chemistry-Labs/radicalpy/tree/main/docs/quick-start/guide.org)
or the
[examples](https://github.com/Spin-Chemistry-Labs/radicalpy/tree/main/examples).

The package is still under development.  Basic functionality is
implemented, [documentation](https://radicalpy.readthedocs.io/) is
sparse, testing partial.

If you would like to contact us, please visit the Spin Chemistry Community [Discord server](https://discord.io/spin-chemistry-community/).

## Installation

Install simply using `pip`:

```
pip install radicalpy
```
